#ifndef INC_FMTTokenTypes_hpp_
#define INC_FMTTokenTypes_hpp_

/* $ANTLR 2.7.7 (20130428): "format.g" -> "FMTTokenTypes.hpp"$ */

#ifndef CUSTOM_API
# define CUSTOM_API
#endif

#ifdef __cplusplus
struct CUSTOM_API FMTTokenTypes {
#endif
	enum {
		EOF_ = 1,
		ALL = 4,
		CSTR = 5,
		CSTR1 = 6,
		CSTR2 = 7,
		ESC = 8,
		OCTESC = 9,
		ODIGIT = 10,
		HEXESC = 11,
		HDIGIT = 12,
		CD = 13,
		CE = 14,
		CI = 15,
		CF = 16,
		CG = 17,
		CO = 18,
		CB = 19,
		CS = 20,
		CX = 21,
		CZ = 22,
		CDOT = 23,
		DIGITS = 24,
		CNUMBER = 25,
		CWS = 26,
		FORMAT = 27,
		LBRACE = 28,
		COMMA = 29,
		RBRACE = 30,
		SLASH = 31,
		STRING = 32,
		TL = 33,
		TR = 34,
		TERM = 35,
		NONL = 36,
		Q = 37,
		T = 38,
		X = 39,
		A = 40,
		F = 41,
		D = 42,
		E = 43,
		G = 44,
		I = 45,
		O = 46,
		B = 47,
		Z = 48,
		ZZ = 49,
		C = 50,
		CMOA = 51,
		CMoA = 52,
		CmoA = 53,
		CHI = 54,
		ChI = 55,
		CDWA = 56,
		CDwA = 57,
		CdwA = 58,
		CAPA = 59,
		CApA = 60,
		CapA = 61,
		CMOI = 62,
		CDI = 63,
		CYI = 64,
		CMI = 65,
		CSI = 66,
		CSF = 67,
		PM = 68,
		MP = 69,
		NUMBER = 70,
		DOT = 71,
		CSTRING = 72,
		H = 73,
		L = 74,
		R = 75,
		PERCENT = 76,
		W = 77,
		WHITESPACE = 78,
		CHAR = 79,
		NULL_TREE_LOOKAHEAD = 3
	};
#ifdef __cplusplus
};
#endif
#endif /*INC_FMTTokenTypes_hpp_*/
